OrderType

Enum OrderType 

pub enum OrderType {
    Market,
    Limit,
}
Defines the type of an order in the Kalshi exchange.

This enum is used to specify the nature of the order, particularly how it interacts with the market.

Variants



Market

A market order is executed immediately at the current market price.



Limit

A limit order is set to be executed at a specific price or better.