pub struct Event {
pub event_ticker: String,
pub series_ticker: String,
pub title: String,
pub sub_title: String,
pub mutually_exclusive: bool,
pub category: String,
pub strike_date: Option<String>,
pub strike_period: Option<String>,
pub markets: Option<Vec<Market>>,
}Expand description
Represents an event on the Kalshi exchange.
An event is a prediction market that contains multiple markets for trading. Events can have various statuses and may include nested markets.
Fields
event_ticker: Stringseries_ticker: Stringtitle: Stringsub_title: Stringmutually_exclusive: boolcategory: Stringstrike_date: Option<String>strike_period: Option<String>markets: Option<Vec<Market>>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Event
impl<'de> Deserialize<'de> for Event
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more