pub struct EventPosition {
pub event_exposure: i64,
pub event_ticker: String,
pub fees_paid: i64,
pub realized_pnl: i64,
pub resting_order_count: Option<i32>,
pub total_cost: i64,
}Expand description
A user’s position in a specific event on the Kalshi exchange.
Details the user’s exposure, costs, profits, and the number of resting orders related to a particular event.
Fields
event_exposure: i64The total exposure amount in the event.
event_ticker: StringThe ticker of the event.
fees_paid: i64The total fees paid in the event in cents.
realized_pnl: i64The realized profit or loss in the event in cents.
resting_order_count: Option<i32>The count of resting (active but unfilled) orders in the event.
total_cost: i64The total cost incurred in the event in cents.